#
# spec file for package tdom
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tdom
%if 0%{!?tclscriptdir:1}
%define tclscriptdir %_libdir
%endif
Summary:        A XML/DOM/XPath/XSLT Implementation for Tcl
License:        MPL-2.0
Group:          Development/Libraries/Tcl
Version:        0.9.5
Release:        1.4
URL:            http://tdom.org
BuildRequires:  autoconf
BuildRequires:  libexpat-devel
BuildRequires:  tcl-devel
BuildRequires:  tcllib
Source0:        http://tdom.org/downloads/tdom-%{version}-src.tgz

%description
tDOM combines high performance XML data processing with easy and
powerful Tcl scripting functionality. tDOM should be one of the fastest
ways to manipulate XML with a scripting language and uses very few
memory: for example, the DOM tree of the XML recommendation in XML
(160K) needs only about 450K of memory.

%package devel
Summary:        Development Files for tdom
Group:          Development/Libraries/Tcl
Requires:       tcl-devel
Requires:       tdom = %{version}

%description devel
This package contains files for developing software based on tdom.

%prep
%autosetup  -p1 -n %{name}-%{version}-src

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
autoreconf --force
mkdir build
cd build
CFLAGS="%optflags -DUSE_INTERP_ERRORLINE" ../configure \
	--prefix=%_prefix \
	--libdir=%tcl_archdir \
	--mandir=%_mandir \
	--with-tcl=%_libdir \
	--disable-tdomalloc \
	--with-expat
%make_build
cd ../extensions/tnc
autoreconf --force
CFLAGS="%optflags" ./configure \
	--prefix=%_prefix \
	--libdir=%tcl_archdir \
	--mandir=%_mandir \
	--with-tcl=%_libdir \
	--with-tdom=../../build
%make_build

%check
cd build
make test
cd ../extensions/tnc
make test TCLLIBPATH=../../build EXTRA_PATH=../../build

%install
cd build
make DESTDIR=%buildroot install
make -C ../extensions/tnc DESTDIR=%buildroot install
#chmod 644 %buildroot/%tcl_archdir/*.a

%files
%license MPL_2.0.html LICENSE
%doc ChangeLog CHANGES README.md
%doc %_mandir/man*/*
%tcl_archdir/*
%exclude %tcl_archdir/*Config.sh
%exclude %tcl_archdir/*/*.a

%files devel
%tcl_archdir/*Config.sh
%tcl_archdir/*/*.a
%_includedir/tdom.h

%changelog
* Wed Nov 13 2024 Danilo Chang <ray2501@gmail.com>
- Update to 0.9.5
  * Added the asTypedList method to the domDoc and domNode commands.
  * Added the createFromTypedList method to the dom command.
  * Added the flag -keepTextStart to the expat command.
  * Text node commands created by createNodeCmd of the json type
    NULL, TRUE or FALSE may be called without argument.
  * Changed the error messages of the dom, domDoc and domNode
    commands to mostly confirm to ususal Tcl behaviour.
  * Added the asTclValue method to the domDoc and domNode commands.
* Mon Aug 19 2024 Danilo Chang <ray2501@gmail.com>
- Update to 0.9.4
  * Added the isHTML5CustomName method to the dom command. The
    simple HTML reader now accept HTML5 custom element names.
  * Enhanced the set of recognised entities to HTML 5.
  * Added an optional replacement string argument to the -replace option of
    the dom command method clearString.
  * Added the -list option to the selectNodes method (cascading
    XPath expressions).
  * Made tDOM work with Tcl 9.
  * The XPath functions floor, ceiling and round now return an
    integer (up to size long). Up to now they appended a .0. It's
    the right thing but it is a user visible change.
  * Added the option -replace to the dom command method clearString.
  * Added the node command method getByteIndex.
  * Added the submethod byteIndex to the info method of the schema commands.
  * Added the method asCanonicalXML to the domDoc and domNode commands.
  * Added the options -escapeCR and -escapeTab to the method asXML of
    the domDoc and domNode commands.
* Fri Jun 30 2023 Reinhard Max <max@suse.com>
- Update to 0.9.3
  * Added the options
  - billionLaughsAttackProtectionMaximumAmplification and
  - billionLaughsAttackProtectionActivationThreshold to dom parse
    and the by the xml::parser/expat command created parser
    commands.
  * Schema command methods validate, validatefile and
    validatechannel enhanced with options to control external
    entity resolving.
  * Added option -forest to dom parse.
  * Added commands tdom::fsnewNode and tdom::fsinsertNode.
* Tue Feb  7 2023 Reinhard Max <max@suse.com>
- bsc#1207959: Install binaries and scripts under %%tcl_archdir
- Obsoletes install-libraries-libdir.patch
* Thu Apr 14 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.2
  * Added tdom::schema command.
  * Added -onlyContents and -breakLines to asHTML.
  * Added -indent value "tab" to asXML and asJSON.
  * User configurable separator character between namespace URI
    and local name for XML namespace-aware SAX parser:  Added the
    option -namespaceseparator to the expat command.
  * Added method clearString to the dom command.
  * Updated tested expat to 2.2.9.
  * Changed the license to MPL 2.0.
- Update to 0.9.1
  * The package name is tDOM, but it always has been requested by
    [package require tdom] and now the scripted helper commands in
    tdom.tcl are also in the namespace tdom (not anymore in tDOM).
    The new pullparser command is now also in this namespace.
    There are aliases from the old command names to the new one,
    so there must be nothing done; old scripts will run as they
    did.
  * Added new method attributeNames to domNode (cmds).
  * Added new methods line and column to most pull parser states.
  * More fine grain control about serialization details: new asXML
    options -nogtescape and -noEmptyElementTag.
  * Fixed a potentially dramatic speed problem in case of certain
    classes of XPath expressions if a threads enabled tDOM is
    used, the result set is large and the DOM tree to query was
    altered somewhere before the query by an operation, which
    appended, inserted or replaced a node.
  * Added command tDOM::pullparser, with creates simple XML "pull"
    parser commands.
  * New flag -keepCDATA for [dom parse ...].
- Update to 0.9.0
  * New feature "creating real FQ nodes with *fromScript methods",
    by adding option -namespace to [dom createNodeCmd].
  * Removed hacky check on [load] time if the tclsh and tDOM are
    build with incompatible TCL_UTF_MAX (because it did not work
    anymore with recent tcl because of changes in core).
  * Added JSON support. New -json option to [dom parse].
  * Added HTM5 parser (new -html5 option to [dom parse]).
  * Added options -xmlDeclaration and -encString to the asXML
    method of the domDoc and domNode commands.
  * Improved handling of characters beyond BMP.
  * Added dom method featureinfo.
  * Raised the limit of maximum number of different XML
    namespaceses within one DOM tree to 2^31.
- Drop upstream fixed tdom-expat.patch
- Replace tdom.patch and tdom-tnc.patch with install-libraries-libdir.patch
* Mon Jul  1 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static
  library (boo#1138797).
* Thu Jun 20 2013 max@suse.com
- Add -DUSE_INTERP_ERRORLINE to fix build with Tcl 8.6.
* Mon Jun 18 2012 gber@opensuse.org
- update to version 0.8.3
  - numerous bugfixes, see ChangeLog for a detailed list of changes
- split off devel subpackage for stubs table, header and config
  script
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed Aug 15 2007 max@suse.de
- Update to the final 0.8.2 release
  * Correct a licensing issue
  * Some cosmetical fixes
* Wed Aug  8 2007 max@suse.de
- New version: 0.8.2rc3
  * Update to expat 2.0.1.
  * Improve 64bit support
  * Added the '-namespaces' option to the selectNodes method.
  * Added the methods 'transform' and 'delete' to xsltCmds.
  * Added the 'selectNodesNamespace' to documents.
  * Normalize case of attribute also (not only elements).
  * Added method deleteXPathCache: basic control over the xpath
    expression cache.
  * Variable references in XPath queries will now be resoved as
    Tcl variables.
- Added tcllib to BuildRequires (needed for 'make test').
- Added the tnc extension to the package
* Fri Apr 27 2007 aj@suse.de
- Add libexpat-devel to BuildRequires.
* Mon Oct  9 2006 max@suse.de
- New package: tdom
- A XML/DOM/XPath/XSLT Implementation for Tcl, based on expat.
- Patched to use the libexpat instead of included copy.
